<?php

namespace Litecms\Activityproject\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Activityproject\Http\Requests\ActivityProjectRequest;
use Litecms\Activityproject\Interfaces\ActivityProjectRepositoryInterface;
use Litecms\Activityproject\Models\ActivityProject;

/**
 * Resource controller class for activity_project.
 */
class ActivityProjectResourceController extends BaseController
{

    /**
     * Initialize activity_project resource controller.
     *
     * @param type ActivityProjectRepositoryInterface $activity_project
     *
     * @return null
     */
    public function __construct(ActivityProjectRepositoryInterface $activity_project)
    {
        parent::__construct();
        $this->repository = $activity_project;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Activityproject\Repositories\Criteria\ActivityProjectResourceCriteria::class);
    }

    /**
     * Display a list of activity_project.
     *
     * @return Response
     */
    public function index(ActivityProjectRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Activityproject\Repositories\Presenter\ActivityProjectPresenter::class)
                ->$function();
        }

        $activity_projects = $this->repository->paginate();

        return $this->response->title(trans('activityproject::activity_project.names'))
            ->view('activityproject::activity_project.index', true)
            ->data(compact('activity_projects', 'view'))
            ->output();
    }

    /**
     * Display activity_project.
     *
     * @param Request $request
     * @param Model   $activity_project
     *
     * @return Response
     */
    public function show(ActivityProjectRequest $request, ActivityProject $activity_project)
    {

        if ($activity_project->exists) {
            $view = 'activityproject::activity_project.show';
        } else {
            $view = 'activityproject::activity_project.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('activityproject::activity_project.name'))
            ->data(compact('activity_project'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new activity_project.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ActivityProjectRequest $request)
    {

        $activity_project = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('activityproject::activity_project.name')) 
            ->view('activityproject::activity_project.create', true) 
            ->data(compact('activity_project'))
            ->output();
    }

    /**
     * Create new activity_project.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ActivityProjectRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $activity_project                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('activityproject::activity_project.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('activityproject/activity_project/' . $activity_project->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/activityproject/activity_project'))
                ->redirect();
        }

    }

    /**
     * Show activity_project for editing.
     *
     * @param Request $request
     * @param Model   $activity_project
     *
     * @return Response
     */
    public function edit(ActivityProjectRequest $request, ActivityProject $activity_project)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('activityproject::activity_project.name'))
            ->view('activityproject::activity_project.edit', true)
            ->data(compact('activity_project'))
            ->output();
    }

    /**
     * Update the activity_project.
     *
     * @param Request $request
     * @param Model   $activity_project
     *
     * @return Response
     */
    public function update(ActivityProjectRequest $request, ActivityProject $activity_project)
    {
        try {
            $attributes = $request->all();

            $activity_project->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('activityproject::activity_project.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('activityproject/activity_project/' . $activity_project->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('activityproject/activity_project/' . $activity_project->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the activity_project.
     *
     * @param Model   $activity_project
     *
     * @return Response
     */
    public function destroy(ActivityProjectRequest $request, ActivityProject $activity_project)
    {
        try {

            $activity_project->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('activityproject::activity_project.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('activityproject/activity_project/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('activityproject/activity_project/' . $activity_project->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple activity_project.
     *
     * @param Model   $activity_project
     *
     * @return Response
     */
    public function delete(ActivityProjectRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('activityproject::activity_project.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('activityproject/activity_project'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/activityproject/activity_project'))
                ->redirect();
        }

    }

    /**
     * Restore deleted activity_projects.
     *
     * @param Model   $activity_project
     *
     * @return Response
     */
    public function restore(ActivityProjectRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('activityproject::activity_project.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/activityproject/activity_project'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/activityproject/activity_project/'))
                ->redirect();
        }

    }

}
