<?php

namespace Litecms\Activityproject\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Activityproject\Models\ActivityProject;

class ActivityProjectPolicy
{

    /**
     * Determine if the given user can view the activity_project.
     *
     * @param UserPolicy $user
     * @param ActivityProject $activity_project
     *
     * @return bool
     */
    public function view(UserPolicy $user, ActivityProject $activity_project)
    {
        if ($user->canDo('activityproject.activity_project.view') && $user->isAdmin()) {
            return true;
        }

        return $activity_project->user_id == user_id() && $activity_project->user_type == user_type();
    }

    /**
     * Determine if the given user can create a activity_project.
     *
     * @param UserPolicy $user
     * @param ActivityProject $activity_project
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('activityproject.activity_project.create');
    }

    /**
     * Determine if the given user can update the given activity_project.
     *
     * @param UserPolicy $user
     * @param ActivityProject $activity_project
     *
     * @return bool
     */
    public function update(UserPolicy $user, ActivityProject $activity_project)
    {
        if ($user->canDo('activityproject.activity_project.edit') && $user->isAdmin()) {
            return true;
        }

        return $activity_project->user_id == user_id() && $activity_project->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given activity_project.
     *
     * @param UserPolicy $user
     * @param ActivityProject $activity_project
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ActivityProject $activity_project)
    {
        return $activity_project->user_id == user_id() && $activity_project->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given activity_project.
     *
     * @param UserPolicy $user
     * @param ActivityProject $activity_project
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ActivityProject $activity_project)
    {
        if ($user->canDo('activityproject.activity_project.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given activity_project.
     *
     * @param UserPolicy $user
     * @param ActivityProject $activity_project
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ActivityProject $activity_project)
    {
        if ($user->canDo('activityproject.activity_project.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
