<?php

namespace Litecms\Activityproject\Providers;

use Illuminate\Support\ServiceProvider;

class ActivityprojectServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'activityproject');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'activityproject');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerActivityproject();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerActivityproject()
    {
        $this->app->bind('activityproject', function($app) {
            return new Activityproject($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Activityproject', 'Lavalite\Activityproject\Facades\Activityproject');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litecms.activityproject', function ($app) {
            return $this->app->make('Litecms\Activityproject\Activityproject');
        });

                // Bind ActivityProject to repository
        $this->app->bind(
            'Litecms\Activityproject\Interfaces\ActivityProjectRepositoryInterface',
            \Litecms\Activityproject\Repositories\Eloquent\ActivityProjectRepository::class
        );

        $this->app->register(\Litecms\Activityproject\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Activityproject\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and activityproject's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/activityproject.php', 'activityproject'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeActivityproject::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.activityproject'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/activityproject.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/activityproject')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/activityproject')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
